==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/jmx/monitoring/configuration/MonitoredAttribute.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2017 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.jmx.monitoring.configuration;

import java.beans.PropertyVetoException;
import javax.xml.bind.annotation.XmlAttribute;
import org.glassfish.api.admin.config.ConfigExtension;
import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.ConfigBeanProxy;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.DuckTyped;

@Configured
public interface MonitoredAttribute extends ConfigBeanProxy, ConfigExtension {

    @XmlAttribute(required = true)
    @Attribute(required = true)
    String getAttributeName();
    void setAttributeName(String value) throws PropertyVetoException;

    @XmlAttribute(required = true)
    @Attribute(required = true)
    String getObjectName();
    void setObjectName(String value) throws PropertyVetoException;

    @XmlAttribute(required = false)
    @Attribute(required = false)
    String getDescription();
    void setDescription(String value) throws PropertyVetoException;

    @DuckTyped
    boolean equals(MonitoredAttribute attr);

    public class Duck {
        public static boolean equals(MonitoredAttribute attr1, MonitoredAttribute attr2) {
            return attr1.getObjectName().equals(attr2.getObjectName())
                    && attr1.getAttributeName().equals(attr2.getAttributeName());
        }
    }

}

==> payara-embedded-all-6.2023.4-sources.jar: fish/payara/jmx/monitoring/configuration/MonitoredAttribute.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2017-2021 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.jmx.monitoring.configuration;

import java.beans.PropertyVetoException;
import jakarta.xml.bind.annotation.XmlAttribute;
import org.glassfish.api.admin.config.ConfigExtension;
import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.ConfigBeanProxy;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.DuckTyped;

@Configured
public interface MonitoredAttribute extends ConfigBeanProxy, ConfigExtension {

    @XmlAttribute(required = true)
    @Attribute(required = true)
    String getAttributeName();
    void setAttributeName(String value) throws PropertyVetoException;

    @XmlAttribute(required = true)
    @Attribute(required = true)
    String getObjectName();
    void setObjectName(String value) throws PropertyVetoException;

    @XmlAttribute(required = false)
    @Attribute(required = false)
    String getDescription();
    void setDescription(String value) throws PropertyVetoException;

    @DuckTyped
    boolean equals(MonitoredAttribute attr);

    public class Duck {
        public static boolean equals(MonitoredAttribute attr1, MonitoredAttribute attr2) {
            return attr1.getObjectName().equals(attr2.getObjectName())
                    && attr1.getAttributeName().equals(attr2.getAttributeName());
        }
    }

}
